# 📚 Bookshelf Suite

The **Bookshelf Suite** is the complete Bookshelf package, combining all modules into one unified bundle.

For more details and usage examples, check out the [documentation](https://docs.mcbookshelf.dev/en/latest/index.html).
